@@ -1,4 +1,5 @@
 use super::settings::InitMode;
+use std::env;
 
 pub struct Init {}
 
@@ -14,6 +15,9 @@ impl Init {
             InitMode::Fish => {
                 Init::init_fish();
             }
+            InitMode::Powershell => {
+                Init::init_pwsh();
+            }
         }
         Self {}
     }
@@ -29,4 +33,9 @@ impl Init {
         let script = include_str!("../mcfly.fish");
         print!("{}", script);
     }
+    pub fn init_pwsh() {
+        let script = include_str!("../mcfly.ps1")
+            .replace("::MCFLY::", env::current_exe().unwrap().to_str().unwrap());
+        print!("{}", script);
+    }
 }
