@@ -92,9 +92,9 @@ impl MenuMode {
         menu_text
     }
 
-    fn bg(&self) -> Color {
+    fn bg(&self, normal: Color) -> Color {
         match *self {
-            MenuMode::Normal => Color::Blue,
+            MenuMode::Normal => normal,
             MenuMode::ConfirmDelete => Color::Red,
         }
     }
@@ -170,8 +170,8 @@ impl<'a> Interface<'a> {
                 cursor::Hide,
                 cursor::MoveTo(0, self.info_line_index()),
                 Clear(ClearType::CurrentLine),
-                SetBackgroundColor(self.menu_mode.bg()),
-                SetForegroundColor(Color::White),
+                SetBackgroundColor(self.menu_mode.bg(self.settings.colors.menubar_bg)),
+                SetForegroundColor(self.settings.colors.menubar_fg),
                 cursor::MoveTo(1, self.info_line_index()),
                 Print(format!(
                     "{text:width$}",
@@ -187,9 +187,9 @@ impl<'a> Interface<'a> {
     fn prompt<W: Write>(&self, screen: &mut W) {
         let prompt_line_index = self.prompt_line_index();
         let fg = if self.settings.lightmode {
-            Color::Black
+            self.settings.colors.lightmode_colors.prompt
         } else {
-            Color::White
+            self.settings.colors.darkmode_colors.prompt
         };
         queue!(
             screen,
@@ -226,28 +226,28 @@ impl<'a> Interface<'a> {
         let mut index: usize = 0;
         for command in self.matches.iter() {
             let mut fg = if self.settings.lightmode {
-                Color::Black
+                self.settings.colors.lightmode_colors.results_fg
             } else {
-                Color::White
+                self.settings.colors.darkmode_colors.results_fg
             };
 
             let mut highlight = if self.settings.lightmode {
-                Color::DarkBlue
+                self.settings.colors.lightmode_colors.results_hl
             } else {
-                Color::DarkGreen
+                self.settings.colors.darkmode_colors.results_hl
             };
 
             let mut bg = Color::Reset;
 
             if index == self.selection {
                 if self.settings.lightmode {
-                    fg = Color::White;
-                    bg = Color::DarkGrey;
-                    highlight = Color::Grey;
+                    fg = self.settings.colors.lightmode_colors.results_selection_fg;
+                    bg = self.settings.colors.lightmode_colors.results_selection_bg;
+                    highlight = self.settings.colors.lightmode_colors.results_selection_hl;
                 } else {
-                    fg = Color::Black;
-                    bg = Color::White;
-                    highlight = Color::DarkGreen;
+                    fg = self.settings.colors.darkmode_colors.results_selection_fg;
+                    bg = self.settings.colors.darkmode_colors.results_selection_bg;
+                    highlight = self.settings.colors.darkmode_colors.results_selection_hl;
                 }
             }
 
@@ -310,9 +310,9 @@ impl<'a> Interface<'a> {
                 .join(" ");
 
                 let timing_color = if self.settings.lightmode {
-                    Color::DarkBlue
+                    self.settings.colors.lightmode_colors.timing
                 } else {
-                    Color::Blue
+                    self.settings.colors.darkmode_colors.timing
                 };
                 queue!(
                     screen,
@@ -452,45 +452,54 @@ impl<'a> Interface<'a> {
                 read().unwrap_or_else(|e| panic!("McFly error: failed to read input {:?}", &e));
             self.debug_cursor(&mut screen);
 
-            if let Event::Key(key_event) = event {
-                if self.menu_mode != MenuMode::Normal {
-                    match key_event {
-                        KeyEvent {
-                            modifiers: KeyModifiers::CONTROL,
-                            code: Char('c') | Char('d') | Char('g') | Char('z') | Char('r'),
-                            ..
-                        } => {
-                            self.run = false;
-                            self.input.clear();
-                            break;
-                        }
-                        KeyEvent {
-                            code: Char('y') | Char('Y'),
-                            ..
-                        } => {
-                            self.confirm(true);
-                        }
-                        KeyEvent {
-                            code: Char('n') | Char('N'),
-                            ..
-                        }
-                        | KeyEvent {
-                            code: KeyCode::Esc, ..
-                        } => {
-                            self.confirm(false);
-                        }
-                        _ => {}
-                    };
-                } else {
+            match self.menu_mode {
+                MenuMode::Normal => {
                     let early_out = match self.settings.key_scheme {
-                        KeyScheme::Emacs => self.select_with_emacs_key_scheme(key_event),
-                        KeyScheme::Vim => self.select_with_vim_key_scheme(key_event),
+                        KeyScheme::Emacs => self.select_with_emacs_key_scheme(event),
+                        KeyScheme::Vim => {
+                            if let Event::Key(key_event) = event {
+                                self.select_with_vim_key_scheme(key_event)
+                            } else {
+                                false
+                            }
+                        }
                     };
 
                     if early_out {
                         break;
                     }
                 }
+                MenuMode::ConfirmDelete => {
+                    if let Event::Key(key_event) = event {
+                        match key_event {
+                            KeyEvent {
+                                modifiers: KeyModifiers::CONTROL,
+                                code: Char('c') | Char('d') | Char('g') | Char('z') | Char('r'),
+                                ..
+                            } => {
+                                self.run = false;
+                                self.input.clear();
+                                break;
+                            }
+                            KeyEvent {
+                                code: Char('y') | Char('Y'),
+                                ..
+                            } => {
+                                self.confirm(true);
+                            }
+                            KeyEvent {
+                                code: Char('n') | Char('N'),
+                                ..
+                            }
+                            | KeyEvent {
+                                code: KeyCode::Esc, ..
+                            } => {
+                                self.confirm(false);
+                            }
+                            _ => {}
+                        }
+                    }
+                }
             }
 
             self.results(&mut screen);
@@ -509,7 +518,21 @@ impl<'a> Interface<'a> {
         terminal::disable_raw_mode().unwrap();
     }
 
-    fn select_with_emacs_key_scheme(&mut self, event: KeyEvent) -> bool {
+    fn select_with_emacs_key_scheme(&mut self, event: Event) -> bool {
+        match event {
+            Event::Key(event) => self.handle_emacs_keyevent(event),
+            Event::Paste(s) => {
+                for i in s.chars() {
+                    self.input.insert(i);
+                }
+                self.refresh_matches(true);
+                false
+            }
+            _ => false,
+        }
+    }
+
+    fn handle_emacs_keyevent(&mut self, event: KeyEvent) -> bool {
         if event.kind != KeyEventKind::Press {
             return false;
         }
@@ -808,6 +831,13 @@ impl<'a> Interface<'a> {
                         }
                     }
                 }
+                KeyEvent {
+                    code: KeyCode::F(3),
+                    ..
+                } => {
+                    self.switch_result_filter();
+                    self.refresh_matches(true);
+                }
                 _ => {}
             }
         } else {
@@ -937,6 +967,13 @@ impl<'a> Interface<'a> {
                         }
                     }
                 }
+                KeyEvent {
+                    code: KeyCode::F(3),
+                    ..
+                } => {
+                    self.switch_result_filter();
+                    self.refresh_matches(true);
+                }
                 _ => {}
             }
         }
